@@ -61,12 +61,14 @@ class GitClone(object):
         if get_root(directory) is None:
             raise RuntimeError("Provided directory, '" + str(directory) + \
                                "', is not a git repository")
+        self.track_all = track_all
+        if self.track_all:
+            track_branches(directory=directory)
+        self.current_branches = get_branches()
         self.tmp_dir = tempfile.mkdtemp()
         self.clone_dir = os.path.join(self.tmp_dir, 'clone')
         self.repo_url = 'file://' + os.path.abspath(self.directory)
         execute_command('git clone ' + self.repo_url + ' ' + self.clone_dir)
-        if track_all:
-            track_branches(directory=directory)
 
     def __del__(self):
         self.clean_up()
@@ -74,6 +76,8 @@ class GitClone(object):
     def __enter__(self):
         self.orig_cwd = os.getcwd()
         os.chdir(self.clone_dir)
+        if self.track_all:
+            track_branches(directory=self.clone_dir)
         return os.getcwd()
 
     def __exit__(self, exc_type, exc_value, traceback):
@@ -87,8 +91,16 @@ class GitClone(object):
     def commit(self):
         with inbranch(get_commit_hash(get_current_branch())):
             with change_directory(self.clone_dir):
-                execute_command('git push --force --all')
-                execute_command('git push --force --tags')
+                new_branches = get_branches()
+                for branch in self.current_branches:
+                    new_branches.remove(branch)
+                for branch in get_branches(local_only=True):
+                    if branch not in new_branches:
+                        with inbranch(branch):
+                            cmd = 'git pull --rebase origin ' + branch
+                            execute_command(cmd)
+                execute_command('git push --all')
+                execute_command('git push --tags')
         self.clean_up()
 
 
